############
Legal Notice
############

*******
License
*******

`MIT License <https://opensource.org/licenses/MIT>`_

Copyright (C) 2016-2022 Leander Kotzur, Maximilian Hoffmann, Peter Markewitz, Martin Robinius, Detlef Stolten

***************
Acknowledgement
***************

The development of this software is currently supported bby The authors acknowledge the financial support by the Federal Ministry 
for Economic Affairs and Energy of Germany in the project METIS (project number 03ET4064A).

.. image:: https://www.bmwi.de/SiteGlobals/BMWI/StyleBundles/Bilder/bmwi_logo_en.svgz?__blob=normal&v=10
    :target: https://www.bmwi.de/Navigation/EN/Home/home.html
    :width: 200px
    :alt: METIS Logo
    :align: center

.. image:: http://www.metis-platform.net/SiteGlobals/StyleBundles/Bilder/NeuesLayout/metis-platform/logo.jpg?__blob=normal
    :target: http://www.metis-platform.net/metis-platform/EN/Home/_node.html
    :width: 200px
    :alt: METIS Logo
    :align: center

Further, this work was supported by the Helmholtz Association under the Joint Initiative `"Energy System 2050 A Contribution of
the Research Field Energy" <https://www.helmholtz.de/en/research/energy/energy_system_2050/>`_.

.. image:: https://www.helmholtz.de/fileadmin/user_upload/05_aktuelles/Marke_Design/logos/HG_LOGO_S_ENG_RGB.jpg
    :target: https://www.helmholtz.de/en/
    :width: 200px
    :alt: Helmholtz Logo
    :align: center